@@ -373,10 +373,10 @@ void command_list(struct var *var)
             }
 
             if(matchgroup(var->postgroups,g->group))
-               sockprintf(var,"%s %lu %lu y" CRLF,g->tagname,min,max);
+               sockprintf(var,"%s %lu %lu y" CRLF,g->tagname,max,min);
 
             else
-               sockprintf(var,"%s %lu %lu n" CRLF,g->tagname,min,max);
+               sockprintf(var,"%s %lu %lu n" CRLF,g->tagname,max,min);
          }
       }
    }
@@ -1378,7 +1378,7 @@ void command_xover(struct var *var)
                stripctrl(mimesubj);
                stripctrl(mimefrom);
 
-               sprintf(xoverres,"%ld\t%s\t%s\t%s\t%s\t%s\t\t" CRLF,
+               sprintf(xoverres,"%ld\t%s\t%s\t%s\t%s\t%s\t\t\t" CRLF,
                      c,mimesubj,mimefrom,datebuf,msgid,reply);
 
                socksendtext(var,xoverres);
